@@ -8,8 +8,5 @@ if($count[0] eq 0){
   $m_oDatabase->void("UPDATE exploit  set count =count+1 where remote_addr = ? && query_string = ?",$remote_addr,$query_string);
 }
 $m_sContent .= $@ if $@;
-$m_sContent .= qq(
-<div align="center">Welcome  $m_sUser you should  login <br/>
-<img src="/images/preview.jpg" width="" height="" onclick="this.style.width='';"/>
-</div>);
+$m_sContent .= qq(<img src="images/preview.png" width="950" height="314" border="0"/>);
 1;
\ No newline at end of file
