@@ -1,37 +1,37 @@
 $VAR1 = {
+          'admin' => {
+                       'firstname' => 'Dirk',
+                       'password' => 'testpass',
+                       'email' => 'dirk.lze@gmail.com',
+                       'name' => 'Lindner'
+                     },
+          'translate' => '/var/www/cgi-bin/config/translate.pl',
+          'language' => 'en',
           'database' => {
-                          'CurrentDb' => 'LZE',
                           'host' => 'localhost',
                           'password' => 'wertvoll',
-                          'CurrentUser' => 'root',
-                          'user' => 'root',
+                          'name' => 'LZE',
                           'CurrentPass' => 'wertvoll',
                           'CurrentHost' => 'localhost',
-                          'name' => 'LZE'
+                          'user' => 'root',
+                          'CurrentDb' => 'LZE',
+                          'CurrentUser' => 'root'
                         },
+          'config' => '/var/www/cgi-bin/config/settings.pl',
           'cgi' => {
-                     'title' => 'MySQL::Admin',
+                     'DocumentRoot' => '/var/www/htdocs',
                      'cookiePath' => '/',
                      'style' => 'mysql',
-                     'serverName' => 'http://localhost',
                      'expires' => '+1y',
+                     'serverName' => 'http://localhost',
+                     'title' => 'MySQL::Admin',
                      'alias' => 'cgi-bin',
-                     'bin' => '/var/www/cgi-bin',
-                     'DocumentRoot' => '/var/www/htdocs'
+                     'bin' => '/var/www/cgi-bin'
                    },
-          'config' => '/var/www/cgi-bin/config/settings.pl',
           'scriptAlias' => 'cgi-bin',
-          'admin' => {
-                       'email' => 'dirk.lze@gmail.com',
-                       'name' => 'Lindner',
-                       'firstname' => 'Dirk',
-                       'password' => 'testpass'
-                     },
-          'language' => 'en',
-          'session' => '/var/www/cgi-bin/config/session.pl',
-          'version' => '0.68',
-          'translate' => '/var/www/cgi-bin/config/translate.pl',
+          'actions' => '/var/www/cgi-bin/config/actions.pl',
           'floodtime' => 10,
-          'actions' => '/var/www/cgi-bin/config/actions.pl'
+          'session' => '/var/www/cgi-bin/config/session.pl',
+          'version' => '0.69'
         };
 $m_hrSettings =$VAR1;
\ No newline at end of file
